Core Helpers for Asyncio Google Cloud Library
=============================================

This library is not meant to be a standalone project, rather it is used by
various ``gcloud-aio-*`` packages.

|pypi| |pythons|

Installation
------------

.. code-block:: console

    $ pip install --upgrade gcloud-aio-core

.. |pypi| image:: https://img.shields.io/pypi/v/gcloud-aio-core.svg?style=flat-square
    :alt: Latest PyPI Version
    :target: https://pypi.org/project/gcloud-aio-core/

.. |pythons| image:: https://img.shields.io/pypi/pyversions/gcloud-aio-core.svg?style=flat-square
    :alt: Python Version Support
    :target: https://pypi.org/project/gcloud-aio-core/
